@@ -1,6 +1,6 @@
 package Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC::CRUD;
 {
-  $Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC::CRUD::VERSION = '2.120250';
+  $Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC::CRUD::VERSION = '2.122400';
 }
 
 use strict;
@@ -261,8 +261,11 @@ sub list {
             else {
                 # proxy cols must be called as accessors, but normally we'd
                 # prefer to use get_column, so try both, otherwise empty str
-                $data->{$col} = eval{$row->get_column($col)}
-                    ? eval{$row->get_column($col)} : (eval{$row->$col} || '');
+
+                my $evalue = eval{$row->get_column($col)};
+                if ($@) { $evalue = eval{$row->$col} }
+                if ($@) { $evalue = '' }
+                $data->{$col} = (defined $evalue ? $evalue : '');
             }
         }
 
